import sqlite3 from "sqlite3";
import fs from "fs";
const dbDirectory = "./db";
const dbFilePath = `${dbDirectory}/database.db`;

// Créer le répertoire db s'il n'existe pas
if (!fs.existsSync(dbDirectory)) {
  fs.mkdirSync(dbDirectory);
}

// Ouverture de la base de données
let db = new sqlite3.Database(
  dbFilePath,
  sqlite3.OPEN_READWRITE | sqlite3.OPEN_CREATE,
  (err: Error | null) => {
    if (err) console.error(err.message);
  }
);

// Création de la table registered_user dans la base de données

const tableRegisteredUser = `CREATE TABLE IF NOT EXISTS registered_user (id_user INTEGER PRIMARY KEY AUTOINCREMENT, login TEXT NOT NULL, password TEXT NOT NULL, permissions INTEGER NOT NULL, UNIQUE (login))`;

// Exécution de la requête pour créer la table
db.run(tableRegisteredUser, [], function (err) {
  if (err) {
    return console.error(err.message);
  }
  console.log("Table créée avec succès");
});

// Insertion d'un utilisateur dans la table registered_user

const insertUser = `INSERT INTO registered_user (login, password, permissions) VALUES ('admin', 'admin', 1)`;

// Exécution de la requête pour insérer un utilisateur
db.run(insertUser, [], function (err) {
  if (err) {
    return console.error(err.message);
  }
  console.log(`Utilisateur inséré avec succès`);
});

// SELECT de tous les utilisateurs de la table registered_user

const selectAllUsers = `SELECT * FROM registered_user`;

// Exécution de la requête pour sélectionner tous les utilisateurs

db.all(selectAllUsers, [], (err, rows) => {
  if (err) {
    throw err;
  }
  rows.forEach((row) => {
    console.log(row);
  });
});

// Fermeture de la base de données
db.close((err) => {
  if (err) {
    console.error(err.message);
  }
  console.log("Close the database connection.");
});
